/**
 * Copyright © 2021 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
import { ifToggledOn } from '@bodiless/core';
import negate from 'lodash/negate';
import { stylable, withDesign, flowHoc, addProps, } from '@bodiless/fclasses';
import { useIsBreadcrumbItemCurrentPage, useIsLastBreadcrumbItemRenderedAsALink, } from './hooks';
/**
 * Makes all Breadcrumb design components stylable.
 */
export var asStylableBreadcrumbs = withDesign({
    StartingTrail: stylable,
    Separator: stylable,
    Wrapper: stylable,
    BreadcrumbItem: stylable,
    Title: stylable,
    FinalTrail: stylable,
    Item: stylable,
});
/**
 * Applies supplied tokenDefs to all breadcrumb items.
 *
 * @returns HOC - a token that applies provided tokenDefs to all breadcrumb items.
 */
export var withBreadcrumbItemToken = function () {
    var tokenDefs = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        tokenDefs[_i] = arguments[_i];
    }
    return withDesign({
        // dummy arg is needed bc of ts bug, see https://github.com/microsoft/TypeScript/issues/28010
        StartingTrail: flowHoc.apply(void 0, __spreadArray([{}], tokenDefs, false)),
        FinalTrail: flowHoc.apply(void 0, __spreadArray([{}], tokenDefs, false)),
        Title: flowHoc.apply(void 0, __spreadArray([{}], tokenDefs, false)),
    });
};
/**
 * Hoc to make breadcrumbs accessible
 */
export var asAccessibleBreadcrumbs = flowHoc(withDesign({
    NavWrapper: addProps({
        'aria-label': 'Breadcrumb',
    }),
}), ifToggledOn(negate(useIsLastBreadcrumbItemRenderedAsALink))(withDesign({
    Item: ifToggledOn(useIsBreadcrumbItemCurrentPage)(addProps({
        'aria-current': 'page',
    })),
})));
//# sourceMappingURL=Breadcrumb.token.js.map