/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
declare type BreadcrumbItemTitle = {
    data: string | object;
    nodePath: string;
};
declare type BreadcrumbItemLink = {
    data: string;
    nodePath: string;
};
declare type BreadcrumbItemSettings = {
    uuid: string;
    parent?: BreadcrumbItemType;
    title: BreadcrumbItemTitle;
    link: BreadcrumbItemLink;
    store: BreadcrumbStoreType;
};
export declare type BreadcrumbItemType = {
    setTitle: (title: BreadcrumbItemTitle) => void;
    setLink: (link: BreadcrumbItemLink) => void;
    uuid: string;
    title: BreadcrumbItemTitle;
    link: BreadcrumbItemLink;
    isSubpathOf: (item: BreadcrumbItemType | string) => boolean;
    hasPath: (item: BreadcrumbItemType | string) => boolean;
    isAncestorOf: (item: BreadcrumbItemType) => boolean;
    isDescendantOf: (item: BreadcrumbItemType) => boolean;
    isEqual: (item: BreadcrumbItemType | string) => boolean;
    isFirst: () => boolean;
    isLast: () => boolean;
    isActive: () => boolean;
    getAncestors: () => BreadcrumbItemType[];
    parent: BreadcrumbItemType | undefined;
};
/**
 * Stores breadcrumb item data.
 */
export declare class BreadcrumbItem implements BreadcrumbItemType {
    _uuid: string;
    _parent?: BreadcrumbItemType;
    _title: BreadcrumbItemTitle;
    _link: BreadcrumbItemLink;
    _store: BreadcrumbStoreType;
    constructor({ uuid, title, link, store, parent, }: BreadcrumbItemSettings);
    isActive(): boolean;
    isSubpathOf(item: BreadcrumbItemType | string): boolean;
    hasPath(item: BreadcrumbItemType | string): boolean;
    isDescendantOf(item: BreadcrumbItemType): boolean;
    isAncestorOf(item: BreadcrumbItemType): boolean;
    isEqual(item: BreadcrumbItemType | string): boolean;
    isFirst(): boolean;
    isLast(): boolean;
    getAncestors(): BreadcrumbItemType[];
    get uuid(): string;
    get title(): BreadcrumbItemTitle;
    get link(): BreadcrumbItemLink;
    get parent(): BreadcrumbItemType | undefined;
    setTitle(title: BreadcrumbItemTitle): void;
    setLink(link: BreadcrumbItemLink): void;
    toString(): string;
}
export declare type BreadcrumbStoreType = {
    getItem: (key: string) => BreadcrumbItemType | undefined;
    setItem: (item: BreadcrumbItemType) => BreadcrumbItemType | undefined;
    deleteItem: (item: BreadcrumbItemType | string) => boolean;
    getPagePath: () => string;
    breadcrumbTrail: BreadcrumbItemType[];
    export: () => BreadcrumbItemType[];
    hasCurrentPageItem: () => boolean;
};
/**
 * MobX storage of breadcrumb items.
 * API:
 * + set/delete item.
 * + get breadcrumb trail.
 * + check if last breadcrumb item exists in the store.
 */
export declare class BreadcrumbStore implements BreadcrumbStoreType {
    private items;
    private activeItem?;
    private pagePath;
    constructor(pagePath: string);
    private setActiveItem;
    private isNewActive;
    private updateActive;
    private isActiveItemPathChanged;
    getItem(key: string): BreadcrumbItemType | undefined;
    setItem(item: BreadcrumbItemType): BreadcrumbItemType;
    deleteItem(item: BreadcrumbItemType | string): boolean;
    getPagePath(): string;
    get breadcrumbTrail(): BreadcrumbItemType[];
    export(): BreadcrumbItemType[];
    hasCurrentPageItem(): boolean;
    toString(): string;
}
export {};
//# sourceMappingURL=BreadcrumbStore.d.ts.map