/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
/* eslint-disable no-underscore-dangle */
import { observable, action, computed, makeObservable, } from 'mobx';
var DEFAULT_URL_BASE = 'http://host';
var trimTrailingSlash = function (str) { return str.replace(/\/$/, ''); };
var isChildOf = function (child, parent) {
    if (child === parent)
        return false;
    var childTokens = child.split('/').filter(function (i) { return i.length; });
    var parentTokens = parent.split('/').filter(function (i) { return i.length; });
    return parentTokens.every(function (t, i) { return childTokens[i] === t; });
};
/**
 * Stores breadcrumb item data.
 */
var BreadcrumbItem = /** @class */ (function () {
    function BreadcrumbItem(_a) {
        var uuid = _a.uuid, title = _a.title, link = _a.link, store = _a.store, parent = _a.parent;
        Object.defineProperty(this, "_uuid", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_parent", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_title", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_link", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "_store", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this._uuid = uuid;
        this._parent = parent;
        this._title = title;
        this._link = link;
        this._store = store;
    }
    Object.defineProperty(BreadcrumbItem.prototype, "isActive", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function () {
            var _this = this;
            return Boolean(this._store.breadcrumbTrail.find(function (tItem) { return tItem.isEqual(_this); }));
        }
    });
    Object.defineProperty(BreadcrumbItem.prototype, "isSubpathOf", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (item) {
            var base = DEFAULT_URL_BASE;
            var itemURL = typeof item === 'string' ? new URL(item, base) : new URL(item.link.data, base);
            var thisURL = new URL(this.link.data, base);
            if (/^#/.test(this.link.data) || itemURL.host !== thisURL.host)
                return false;
            return isChildOf(itemURL.pathname, thisURL.pathname);
        }
    });
    Object.defineProperty(BreadcrumbItem.prototype, "hasPath", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (item) {
            var base = DEFAULT_URL_BASE;
            var itemURL = typeof item === 'string' ? new URL(item, base) : new URL(item.link.data, base);
            var thisURL = new URL(this.link.data, base);
            if (/^#/.test(this.link.data) || itemURL.host !== thisURL.host)
                return false;
            return trimTrailingSlash(thisURL.pathname) === trimTrailingSlash(itemURL.pathname);
        }
    });
    Object.defineProperty(BreadcrumbItem.prototype, "isDescendantOf", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (item) {
            for (var current = this._parent; current; current = this._parent)
                if (current === item)
                    return true;
            return false;
        }
    });
    Object.defineProperty(BreadcrumbItem.prototype, "isAncestorOf", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (item) {
            var isDescendant = item.isDescendantOf(this);
            return isDescendant;
        }
    });
    Object.defineProperty(BreadcrumbItem.prototype, "isEqual", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (item) {
            var uuid = typeof item === 'string' ? item : item.uuid;
            return uuid === this._uuid;
        }
    });
    Object.defineProperty(BreadcrumbItem.prototype, "isFirst", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function () {
            return this.parent === undefined;
        }
    });
    Object.defineProperty(BreadcrumbItem.prototype, "isLast", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function () {
            var lastTrailItem = this._store.breadcrumbTrail[this._store.breadcrumbTrail.length - 1];
            return this._uuid === lastTrailItem.uuid;
        }
    });
    Object.defineProperty(BreadcrumbItem.prototype, "getAncestors", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function () {
            var ancestors = [];
            for (var current = this._parent; current; current = current.parent) {
                ancestors.push(current);
            }
            return ancestors;
        }
    });
    Object.defineProperty(BreadcrumbItem.prototype, "uuid", {
        get: function () {
            return this._uuid;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BreadcrumbItem.prototype, "title", {
        get: function () {
            return this._title;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BreadcrumbItem.prototype, "link", {
        get: function () {
            return this._link;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BreadcrumbItem.prototype, "parent", {
        get: function () {
            return this._parent;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BreadcrumbItem.prototype, "setTitle", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (title) {
            this._title = title;
        }
    });
    Object.defineProperty(BreadcrumbItem.prototype, "setLink", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (link) {
            this._link = link;
        }
    });
    Object.defineProperty(BreadcrumbItem.prototype, "toString", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function () {
            return "[".concat(this.link.data).concat(this.isActive() ? '***' : '', "](").concat(this.uuid, ")");
        }
    });
    return BreadcrumbItem;
}());
export { BreadcrumbItem };
/**
 * MobX storage of breadcrumb items.
 * API:
 * + set/delete item.
 * + get breadcrumb trail.
 * + check if last breadcrumb item exists in the store.
 */
var BreadcrumbStore = /** @class */ (function () {
    function BreadcrumbStore(pagePath) {
        // eslint-disable-next-line max-len
        Object.defineProperty(this, "items", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: new Map()
        });
        Object.defineProperty(this, "activeItem", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: undefined
        });
        Object.defineProperty(this, "pagePath", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.pagePath = pagePath;
        makeObservable(this);
    }
    Object.defineProperty(BreadcrumbStore.prototype, "setActiveItem", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (item) {
            this.activeItem = item;
        }
    });
    Object.defineProperty(BreadcrumbStore.prototype, "isNewActive", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (item) {
            return (item.hasPath(this.pagePath) || item.isSubpathOf(this.pagePath))
                && (!this.activeItem || this.activeItem.isSubpathOf(item));
        }
    });
    Object.defineProperty(BreadcrumbStore.prototype, "updateActive", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function () {
            var _this = this;
            this.setActiveItem(undefined);
            this.items.forEach(function (item) {
                if (_this.isNewActive(item))
                    _this.setActiveItem(item);
            });
        }
    });
    Object.defineProperty(BreadcrumbStore.prototype, "isActiveItemPathChanged", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (item) {
            return this.activeItem !== undefined
                && this.activeItem.isEqual(item)
                && !this.activeItem.hasPath(item);
        }
    });
    Object.defineProperty(BreadcrumbStore.prototype, "getItem", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (key) {
            return this.items.get(key);
        }
    });
    Object.defineProperty(BreadcrumbStore.prototype, "setItem", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (item) {
            this.items.set(item.uuid, item);
            if (this.isActiveItemPathChanged(item))
                this.updateActive();
            if (this.isNewActive(item))
                this.setActiveItem(item);
            return item;
        }
    });
    Object.defineProperty(BreadcrumbStore.prototype, "deleteItem", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (item) {
            var uuid = typeof item === 'string' ? item : item.uuid;
            var result = this.items.delete(uuid);
            if (this.activeItem !== undefined
                && this.activeItem.isEqual(item))
                this.updateActive();
            return result;
        }
    });
    Object.defineProperty(BreadcrumbStore.prototype, "getPagePath", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function () {
            return this.pagePath;
        }
    });
    Object.defineProperty(BreadcrumbStore.prototype, "breadcrumbTrail", {
        get: function () {
            if (this.activeItem === undefined)
                return [];
            return __spreadArray([
                this.activeItem
            ], this.activeItem.getAncestors(), true).reverse();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BreadcrumbStore.prototype, "export", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function () {
            return Array.from(this.items.values());
        }
    });
    Object.defineProperty(BreadcrumbStore.prototype, "hasCurrentPageItem", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function () {
            return this.activeItem !== undefined && this.activeItem.hasPath(this.pagePath);
        }
    });
    Object.defineProperty(BreadcrumbStore.prototype, "toString", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function () {
            return this.breadcrumbTrail.map(function (i) { return i.toString(); }).join('--');
        }
    });
    __decorate([
        observable,
        __metadata("design:type", Map)
    ], BreadcrumbStore.prototype, "items", void 0);
    __decorate([
        observable,
        __metadata("design:type", Object)
    ], BreadcrumbStore.prototype, "activeItem", void 0);
    __decorate([
        action,
        __metadata("design:type", Function),
        __metadata("design:paramtypes", [Object]),
        __metadata("design:returntype", void 0)
    ], BreadcrumbStore.prototype, "setActiveItem", null);
    __decorate([
        action,
        __metadata("design:type", Function),
        __metadata("design:paramtypes", [Object]),
        __metadata("design:returntype", void 0)
    ], BreadcrumbStore.prototype, "setItem", null);
    __decorate([
        action,
        __metadata("design:type", Function),
        __metadata("design:paramtypes", [Object]),
        __metadata("design:returntype", void 0)
    ], BreadcrumbStore.prototype, "deleteItem", null);
    __decorate([
        computed,
        __metadata("design:type", Object),
        __metadata("design:paramtypes", [])
    ], BreadcrumbStore.prototype, "breadcrumbTrail", null);
    return BreadcrumbStore;
}());
export { BreadcrumbStore };
//# sourceMappingURL=BreadcrumbStore.js.map