/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ComponentType } from 'react';
import { HOC } from '@bodiless/fclasses';
import type { BreadcrumbStoreType } from './BreadcrumbStore';
/**
 * Component that adds react context provider containing store to its children.
 */
declare const BreadcrumbStoreProvider: ComponentType<any>;
/**
 * React hook to get store.
 */
declare const useBreadcrumbStore: () => BreadcrumbStoreType | undefined;
/**
 * @private
 *
 * Wrap a breadcrumb source which is rendered only on the server to populate
 * the store before any components which need breadcrumb store data are
 * rendered.
 *
 * @param Component
 */
declare const asHiddenBreadcrumbSource: HOC;
export { useBreadcrumbStore, BreadcrumbStoreProvider, asHiddenBreadcrumbSource, };
//# sourceMappingURL=BreadcrumbStoreProvider.d.ts.map