/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React from 'react';
import ReactDOMServer from 'react-dom/server';
import { useNode, NodeProvider } from '@bodiless/core';
var BreadcrumbsStoreContext = React.createContext(undefined);
/**
 * Component that adds react context provider containing store to its children.
 */
var BreadcrumbStoreProvider = function (_a) {
    var children = _a.children, store = _a.store;
    return (React.createElement(BreadcrumbsStoreContext.Provider, { value: store }, children));
};
/**
 * React hook to get store.
 */
var useBreadcrumbStore = function () { return React.useContext(BreadcrumbsStoreContext); };
/**
 * @private
 *
 * Wrap a breadcrumb source which is rendered only on the server to populate
 * the store before any components which need breadcrumb store data are
 * rendered.
 *
 * @param Component
 */
var asHiddenBreadcrumbSource = function (Component) {
    var AsHiddenBreadcrumbSource = function (props) {
        var store = useBreadcrumbStore();
        var node = useNode().node;
        ReactDOMServer.renderToString(React.createElement(NodeProvider, { node: node },
            React.createElement(BreadcrumbStoreProvider, { store: store },
                React.createElement(Component, __assign({}, props)))));
        return null;
    };
    return AsHiddenBreadcrumbSource;
};
export { useBreadcrumbStore, BreadcrumbStoreProvider, asHiddenBreadcrumbSource, };
//# sourceMappingURL=BreadcrumbStoreProvider.js.map