/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import type { BreadcrumbsComponents, CleanBreadcrumbsProps } from './types';
/**
 * Clean component that renders breadcrumbs.
 * @see BreadcrumbsComponents for a list of design components.
 */
declare const BreadcrumbsClean: import("@bodiless/fclasses").ComponentWithMeta<import("@bodiless/fclasses").PP<CleanBreadcrumbsProps, import("@bodiless/fclasses").DesignableProps<BreadcrumbsComponents>, import("@bodiless/fclasses").DesignableComponentsProps<BreadcrumbsComponents>>>;
/**
 * HOC that enables rendering of starting trail for a breadcrumb based component.
 * @param Component a breadcrumb based component
 */
declare const withStartingTrail: import("@bodiless/fclasses").Injector<{
    hasStartingTrail: boolean;
}, object>;
/**
 * HOC that disables rendering of starting trail for a breadcrumb based component.
 * @param Component a breadcrumb based component
 */
declare const withoutStartingTrail: import("@bodiless/fclasses").Injector<{
    hasStartingTrail: boolean;
}, object>;
/**
 * HOC that enables rendering of final trail for a breadcrumb based component.
 * @param Component a breadcrumb based component
 */
declare const withFinalTrail: import("@bodiless/fclasses").Injector<{
    hasFinalTrail: boolean;
}, object>;
/**
 * HOC that disables rendering of final trail for a breadcrumb based component.
 * @param Component a breadcrumb based component
 */
declare const withoutFinalTrail: import("@bodiless/fclasses").Injector<{
    hasFinalTrail: boolean;
}, object>;
/**
 * HOC that adds breadcrumb props retrieved from breadcrumb store.
 */
declare const asBreadcrumbs: (...args: any[]) => any;
/**
 * Component that renders breadcrumb items retrieved from breadcrumb store.
 */
declare const MenuBreadcrumbs: any;
export { asBreadcrumbs, BreadcrumbsClean, MenuBreadcrumbs, withStartingTrail as withBreadcrumbStartingTrail, withoutStartingTrail as withoutBreadcrumbStartingTrail, withFinalTrail as withBreadcrumbFinalTrail, withoutFinalTrail as withoutBreadcrumbFinalTrail, };
//# sourceMappingURL=Breadcrumbs.d.ts.map