/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ComponentType } from 'react';
import type { BreadcrumbsProps, BreadcrumbItemType } from './types';
/**
 * removes first item from the trail
 * when there is a custom starting trail and
 * when the first store item has frontpage path
 *
 * @param items - breadcrumb store items
 * @param props - breadcrumb component props
 *
 * @returns uuids - a list of item uuids
 */
declare const firstItemHomeLinkReducer: (items: BreadcrumbItemType[], { hasStartingTrail }: Pick<BreadcrumbsProps, 'hasStartingTrail'>) => string[];
/**
 * HOC that populates a breadcrumb based component with data from breadcrumb store.
 * @param Component a breadcrumb based component
 */
declare const withBreadcrumbItemsFromStore: (Component: ComponentType<BreadcrumbsProps>) => (props: BreadcrumbsProps) => JSX.Element;
export default withBreadcrumbItemsFromStore;
export { firstItemHomeLinkReducer, };
//# sourceMappingURL=withBreadcrumbItemsFromStore.d.ts.map