/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
/* eslint-disable jsx-a11y/anchor-is-valid */
import React from 'react';
import { useNode } from '@bodiless/core';
import { useBreadcrumbStore } from './BreadcrumbStoreProvider';
/**
 * removes first item from the trail
 * when there is a custom starting trail and
 * when the first store item has frontpage path
 *
 * @param items - breadcrumb store items
 * @param props - breadcrumb component props
 *
 * @returns uuids - a list of item uuids
 */
var firstItemHomeLinkReducer = function (items, _a) {
    var hasStartingTrail = _a.hasStartingTrail;
    return items
        .filter(function (item) { return !(hasStartingTrail && item.isFirst() && item.hasPath('/')); })
        .map(function (item) { return item.uuid; });
};
/**
 * HOC that populates a breadcrumb based component with data from breadcrumb store.
 * @param Component a breadcrumb based component
 */
var withBreadcrumbItemsFromStore = function (Component) {
    var WithBreadcrumbItemsFromStore = function (props) {
        var nodeCollection = props.nodeCollection, _a = props.hasStartingTrail, hasStartingTrail = _a === void 0 ? false : _a, _b = props.hasFinalTrail, hasFinalTrail = _b === void 0 ? false : _b, _c = props.itemsReducer, itemsReducer = _c === void 0 ? firstItemHomeLinkReducer : _c, _d = props.renderLastItemWithoutLink, renderLastItemWithoutLink = _d === void 0 ? true : _d, rest = __rest(props, ["nodeCollection", "hasStartingTrail", "hasFinalTrail", "itemsReducer", "renderLastItemWithoutLink"]);
        var store = useBreadcrumbStore();
        if (store === undefined)
            return React.createElement(Component, __assign({}, props));
        var node = useNode(nodeCollection).node;
        var basePath = node.path;
        var items = itemsReducer(store.breadcrumbTrail, { hasStartingTrail: hasStartingTrail })
            .map(function (uuid) { return store.getItem(uuid); })
            // map items retrieved from store
            // into items expected by base breadcrumb component
            /* eslint-disable @typescript-eslint/indent */
            // eslint throws an indentation error for lines inside reduce body
            // automatic eslint fix brings code to unreadable state
            // probably that is an eslint plugin issue
            // the disabled rule is enabled back after reduce
            .reduce(function (prev, current, index) {
            if (current === undefined)
                return prev;
            var titleNodePath = current.title.nodePath.replace("".concat(basePath, "$"), '');
            // @todo probably a better way to get the nodeKey...
            var temp = titleNodePath.split('$');
            var nodeKey = temp.slice(0, temp.length - 1).join('$');
            prev.push({
                uuid: current.uuid,
                nodeKey: nodeKey,
                nodeCollection: nodeCollection,
                position: index + 1,
                isCurrentPage: current.isLast() && store.hasCurrentPageItem(),
            });
            return prev;
        }, []);
        /* eslint-enable @typescript-eslint/indent */
        var hasFinalTrail$0 = typeof hasFinalTrail === 'function' ? hasFinalTrail() : hasFinalTrail;
        var hasFinalTrail$1 = hasFinalTrail$0 && !store.hasCurrentPageItem();
        var lastItemWithoutLink = typeof renderLastItemWithoutLink === 'function'
            ? renderLastItemWithoutLink()
            : renderLastItemWithoutLink;
        var props$1 = __assign(__assign({}, rest), { items: items, hasFinalTrail: hasFinalTrail$1, hasStartingTrail: hasStartingTrail, renderLastItemWithoutLink: lastItemWithoutLink
                && !hasFinalTrail$1
                && store.hasCurrentPageItem() });
        return React.createElement(Component, __assign({}, props$1));
    };
    return WithBreadcrumbItemsFromStore;
};
export default withBreadcrumbItemsFromStore;
export { firstItemHomeLinkReducer, };
//# sourceMappingURL=withBreadcrumbItemsFromStore.js.map