/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { useRef } from 'react';
import { useNode } from '@bodiless/core';
import { BreadcrumbStore } from './BreadcrumbStore';
import { MenuBreadcrumbs } from './Breadcrumbs';
import { BreadcrumbStoreProvider } from './BreadcrumbStoreProvider';
/**
 * HOC that adds breadcrumb store and renders breadcrumbs.
 * @param Component that pushes its data to the store.
 */
export var withBreadcrumbStore = function (Component) {
    var WithBreadcrumbStore = function (props) {
        var node = useNode().node;
        var pagePath = node.pagePath;
        var storeRef = useRef();
        if (storeRef.current === undefined)
            storeRef.current = new BreadcrumbStore(pagePath);
        return (React.createElement(BreadcrumbStoreProvider, { store: storeRef.current },
            React.createElement(Component, __assign({}, props))));
    };
    return WithBreadcrumbStore;
};
/**
 * HOC that adds breadcrumb store and renders breadcrumbs.
 * @param Component that pushes its data to the store.
 */
var withBreadcrumbs = function (Component) {
    var WithBreadcrumbs = function (props) { return (React.createElement(React.Fragment, null,
        React.createElement(Component, __assign({}, props)),
        React.createElement(MenuBreadcrumbs, __assign({}, props)))); };
    return withBreadcrumbStore(WithBreadcrumbs);
};
export default withBreadcrumbs;
//# sourceMappingURL=withBreadcrumbs.js.map