/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { WithNodeKeyProps } from '@bodiless/core';
import { HOC } from '@bodiless/fclasses';
/**
 * Enables rendering of the starting trail for a Breadcrumb component with a provided Editors.
 * Uses `withDefaultMenuTitleEditors` by default, pre-configured with a link to the home page.
 *
 * @param withTitleEditors
 * Editors token that will be applied to the Title key of the StartingTrail component.
 *
 * @param nodeKeys
 * Optional nodeKeys of type `WithNodeKeyProps` that will be applied to the StartingTrail.
 *
 * @return
 * HOC that adds starting trail with provided Title Editors and nodeKeys.
 */
export declare const withEditableStartingTrail: (withTitleEditors?: HOC, nodeKeys?: WithNodeKeyProps | undefined) => import("@bodiless/fclasses").HOCWithMeta<unknown, {}, {
    hasStartingTrail: boolean;
}>;
/**
 * Enables rendering of the final trail for a Breadcrumb component with a provided Editors.
 * Uses `withDefaultMenuTitleEditors` by default.
 *
 * @param withTitleEditors
 * Editors token that will be applied to the Title key of the FinalTrail component.
 *
 * @param nodeKeys
 * Optional nodeKeys of type `WithNodeKeyProps` that will be applied to the FinalTrail.
 *
 * @return
 * HOC that adds final trail with provided Title Editors and nodeKeys.
 */
export declare const withEditableFinalTrail: (withTitleEditors?: HOC, nodeKeys?: WithNodeKeyProps | undefined) => import("@bodiless/fclasses").HOCWithMeta<unknown, {}, {
    hasFinalTrail: boolean;
}>;
//# sourceMappingURL=withEditableTrail.d.ts.map