/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import React from 'react';
import { HOC } from '@bodiless/fclasses';
/**
 * Type of a Burger Menu Context.
 */
declare type BurgerMenuContextType = {
    isVisible: boolean;
    isTransitionComplete: boolean;
    toggle: React.Dispatch<React.SetStateAction<boolean>>;
    setIsTransitionComplete: React.Dispatch<React.SetStateAction<boolean>>;
};
/**
 * A Hook to get the current Burger Menu `isVisible` and `toggle()` context values.
 *
 * @return The current Burger Menu `isVisible` and `toggle()` context values.
 */
declare const useBurgerMenuContext: () => BurgerMenuContextType;
/**
 * @private
 * Wraps component with the BurgerMenuContext and creates two state variables
 * that are passed to the provider:
 *  - `isVisible` - Boolean to toggle Burger Menu visibility.
 *  - `toggle()` - Visibility toggle function.
 *  - `isTransitionComplete` - Boolean that determines if BM transition is completed.
 *  - `setIsTransitionComplete()` - Transition state toggle function.
 *
 */
declare const withBurgerMenuProvider: HOC;
/**
 * Hook which can be used to determine if Burger Menu is visible.
 *
 * @return true if the Burger Menu is visible, false otherwise.
 */
declare const useIsBurgerMenuVisible: () => boolean;
/**
 * Hook which returns `true` if burger menu transitions are completed.
 * Not active means Burger menu is hidden and all animations are completed.
 * This hook useful to prevent hide animations from running when component is
 * initially mounted, but has `isVisible = false`.
 *
 * @return true if the Burger Menu is hidden and all animations are completed.
 */
declare const useIsBurgerTransitionCompleted: () => boolean;
/**
 * Hook which can be used to determine if Burger Menu is hidden.
 *
 * @return true if the Burger Menu is hidden, false otherwise.
 */
declare const useIsBurgerMenuHidden: () => boolean;
export { withBurgerMenuProvider, useBurgerMenuContext, useIsBurgerMenuVisible, useIsBurgerMenuHidden, useIsBurgerTransitionCompleted, };
//# sourceMappingURL=BurgerMenuContext.d.ts.map