/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ComponentType } from 'react';
import { DesignableComponentsProps, HOC } from '@bodiless/fclasses';
export declare type TogglerComponents = {
    Wrapper: ComponentType<any>;
    Button: ComponentType<any>;
};
declare type TogglerProps = DesignableComponentsProps<TogglerComponents>;
/**
 * HOC that adds an ability to toggle Burger Menu visibility on click.
 * It extends Component's default onClick handler if exists. Note that
 * the Component has to be inside a BurgerMenuContext.
 *
 * Also adds default props related to accessibility.
 *
 * @return Original component with extended onClick handler that toggles Burger Menu visibility.
 */
export declare const asBurgerMenuToggler: HOC;
/**
 * Clean Unstyled version of Burger Menu Toggler button.
 * Has an onClick handler that toggles BurgerMenuContext 'isVisible' prop.
 *
 * For this button to work both burger menu and toggler button should be inside BurgerMenuContext.
 *
 * @return Burger Menu default toggler component.
 * @deprecated
 */
declare const BurgerMenuTogglerClean: import("@bodiless/fclasses").ComponentWithMeta<import("@bodiless/fclasses").PP<import("@bodiless/fclasses").PP<TogglerProps, import("@bodiless/fclasses").DesignableProps<TogglerComponents>, DesignableComponentsProps<TogglerComponents>>, {}, {}>>;
/**
 * Default Burger Menu Toggler button. Toggles button icon based on the
 * burger menu state ('close' | 'menu'). Has an onClick handler that toggles
 * BurgerMenuContext 'isVisible' prop.
 *
 * For this button to work both burger menu and toggler button should be inside BurgerMenuContext.
 *
 * @return Burger Menu default toggler component.
 *
 * @deprecated
 */
declare const BurgerMenuDefaultToggler: import("@bodiless/fclasses").ComponentWithMeta<import("@bodiless/fclasses").PP<import("@bodiless/fclasses").PP<import("@bodiless/fclasses").PP<TogglerProps, import("@bodiless/fclasses").DesignableProps<TogglerComponents>, DesignableComponentsProps<TogglerComponents>>, {}, {}>, {}, {}>>;
export { BurgerMenuTogglerClean, BurgerMenuDefaultToggler, };
//# sourceMappingURL=BurgerMenuToggler.d.ts.map