/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React from 'react';
import flow from 'lodash/flow';
import { Fragment, A, designable, } from '@bodiless/fclasses';
import { useBurgerMenuContext } from './BurgerMenuContext';
import { withBurgerMenuTogglerStyles } from './BurgerMenu.token';
import BurgerMenuKeyPressHandler from './BurgerMenuKeyboard';
var TogglerComponents = {
    Wrapper: Fragment,
    Button: A,
};
var TogglerBase = function (_a) {
    var components = _a.components, rest = __rest(_a, ["components"]);
    var Wrapper = components.Wrapper, Button = components.Button;
    var isVisible = useBurgerMenuContext().isVisible;
    return (React.createElement(Wrapper, null,
        React.createElement(Button, __assign({}, rest), isVisible ? 'close' : 'menu')));
};
/**
 * HOC that adds an ability to toggle Burger Menu visibility on click.
 * It extends Component's default onClick handler if exists. Note that
 * the Component has to be inside a BurgerMenuContext.
 *
 * Also adds default props related to accessibility.
 *
 * @return Original component with extended onClick handler that toggles Burger Menu visibility.
 */
export var asBurgerMenuToggler = function (Component) {
    var AsBurgerMenuToggler = function (props) {
        var _a = useBurgerMenuContext(), isVisible = _a.isVisible, toggle = _a.toggle, isTransitionComplete = _a.isTransitionComplete, setIsTransitionComplete = _a.setIsTransitionComplete;
        var onClick = props.onClick, rest = __rest(props, ["onClick"]);
        var extendOnClick = function () {
            if (onClick && typeof onClick === 'function')
                onClick();
            toggle(!isVisible);
            // Wait for the animations to complete then toggle isTransitionComplete.
            // This prevents unnecessary animation plays on initial render
            // as well as when resizing browser viewport to tablet/mobile manually.
            setTimeout(function () { return setIsTransitionComplete(!isTransitionComplete); }, 500);
        };
        return (React.createElement(Component, __assign({ onClick: extendOnClick, tabIndex: "0", role: "button", onKeyPress: function (event) { return BurgerMenuKeyPressHandler(event, isVisible, toggle); }, "aria-expanded": !!isVisible }, rest)));
    };
    return AsBurgerMenuToggler;
};
/**
 * Clean Unstyled version of Burger Menu Toggler button.
 * Has an onClick handler that toggles BurgerMenuContext 'isVisible' prop.
 *
 * For this button to work both burger menu and toggler button should be inside BurgerMenuContext.
 *
 * @return Burger Menu default toggler component.
 * @deprecated
 */
var BurgerMenuTogglerClean = flow(designable(TogglerComponents, 'BurgerMenuToggler'), asBurgerMenuToggler)(TogglerBase);
/**
 * Default Burger Menu Toggler button. Toggles button icon based on the
 * burger menu state ('close' | 'menu'). Has an onClick handler that toggles
 * BurgerMenuContext 'isVisible' prop.
 *
 * For this button to work both burger menu and toggler button should be inside BurgerMenuContext.
 *
 * @return Burger Menu default toggler component.
 *
 * @deprecated
 */
var BurgerMenuDefaultToggler = withBurgerMenuTogglerStyles(BurgerMenuTogglerClean);
export { BurgerMenuTogglerClean, BurgerMenuDefaultToggler, };
//# sourceMappingURL=BurgerMenuToggler.js.map