/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { HOC } from '@bodiless/fclasses';
/**
 * HOC that adds an overview link to a burger menu sublist.  The overview link
 * renders specified text with a link to the destination of the parent menu
 * item.  If the parent menu item is not a link, no overview link will be
 * rendered.
 *
 * This HOC has to be applied on the List level (List, Cards or Column submenus).
 *
 * @param overviewText
 * The text to display or, if your menu titles render using something other
 * than the default title editor, then an object matching the schema of
 * that editor.
 *
 * @return
 * HOC that adds an OverviewLink to the menu list.
 */
declare const withOverviewLink: (overviewText?: any, nodeKeys?: {
    toggleNodeKey: string;
    linkNodeKey: string;
    titleNodeKey: string;
}) => import("@bodiless/fclasses").HOCWithMeta<unknown, object & {
    content?: {
        [x: string]: any;
    } | undefined;
}, {
    prependItems: string[];
}>;
/**
 * HOC that wraps the supplied Component in the burger menu chrome.
 *
 * @param Component Component to be wrapped in the burger menu chrome.
 *
 * @return Original component wrapped in the burger menu chrome with 'Menu' design key.
 */
declare const withBurgerMenuWrapper: HOC;
/**
 * Helper which allows specifying which submenu types are configured
 * by default for the Burger Menu. Transforms selected submenus into accordions.
 *
 * @param keys List of the submenu key(s) to which the default styles will be applied to.
 *
 * @return HOC that applies default burger menu styles based on provided keys.
 */
declare const asBurgerMenu: (...keys: string[]) => import("@bodiless/fclasses").HOCWithMeta<{}, {}, {}>;
export default asBurgerMenu;
export { withBurgerMenuWrapper, withOverviewLink, };
//# sourceMappingURL=asBurgerMenu.d.ts.map