/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ComponentType } from 'react';
import { HOC, HOCDef, DesignableComponentsProps } from '@bodiless/fclasses';
export declare type MenuTitleComponents = {
    Link: ComponentType<any>;
    Title: ComponentType<any>;
};
declare type MenuTitleProps = DesignableComponentsProps<MenuTitleComponents>;
declare const DEFAULT_NODE_KEYS: {
    toggleNodeKey: string;
    linkNodeKey: string;
    titleNodeKey: string;
};
/**
 * Clean component that renders Menu Titles.
 *
 * @see MenuTitleComponents for a list of design components.
 */
declare const MenuTitle: import("@bodiless/fclasses").ComponentWithMeta<import("@bodiless/fclasses").PP<MenuTitleProps, import("@bodiless/fclasses").DesignableProps<MenuTitleComponents>, DesignableComponentsProps<MenuTitleComponents>>>;
/**
 * HOC that adds a default Editors to the menu Title and Link.
 * Transforms Link into Editable Bodiless Link Toggle and Title to Editable.
 */
declare const withDefaultMenuTitleEditors: HOC<{}, {}, {}>;
/**
 * A helper to apply provided `withTitleEditors` HOC to the Title menu key.
 * Applies `withDefaultMenuTitleEditors` token by default.
 *
 * @param withTitleEditors HOC that will be applied to the Title key
 */
declare const withMenuTitleEditors: <P extends object>(withTitleEditors?: HOC, ...tokenDefs: HOCDef[]) => HOC<{}, {}, {}>;
/**
 * HOC that transforms component into MenuTitle with node and 'title' nodeKey.
 * MenuTitle has Link and Title design keys. Can be applied to the Title design key.
 */
declare const asMenuTitle: import("@bodiless/fclasses").HOCWithMeta<{}, import("@bodiless/core").WithNodeProps, import("@bodiless/core").WithNodeProps>;
/**
 * HOC that transforms component into Menu Card with node and 'title' nodeKey.
 * Can be applied to the Title design key.
 */
declare const asMenuCard: import("@bodiless/fclasses").HOCWithMeta<{}, import("@bodiless/core").WithNodeProps, import("@bodiless/core").WithNodeProps>;
export default MenuTitle;
export { DEFAULT_NODE_KEYS, withMenuTitleEditors, withDefaultMenuTitleEditors, asMenuCard, asMenuTitle, };
//# sourceMappingURL=MenuTitles.d.ts.map