/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
import React from 'react';
import { withSidecarNodes, withNode, withNodeKey, } from '@bodiless/core';
import { asEditable, withBodilessLinkToggle } from '@bodiless/components';
import { asBodilessLink } from '@bodiless/components-ui';
import { CardClean } from '@bodiless/card';
import { A, flowHoc, Fragment, designable, withDesign, startWith, } from '@bodiless/fclasses';
var DEFAULT_NODE_KEYS = {
    toggleNodeKey: 'title$link-toggle',
    linkNodeKey: 'title$link',
    titleNodeKey: 'title$text',
};
var MenuTitleBase = function (_a) {
    var components = _a.components, rest = __rest(_a, ["components"]);
    var Link = components.Link, Title = components.Title;
    return (React.createElement(Link, __assign({}, rest),
        React.createElement(Title, null)));
};
var MenuTitleComponents = {
    Link: A,
    Title: Fragment,
};
/**
 * Clean component that renders Menu Titles.
 *
 * @see MenuTitleComponents for a list of design components.
 */
var MenuTitle = designable(MenuTitleComponents, 'MenuTitle')(MenuTitleBase);
var asMenuLink = function (asEditableLink) { return flowHoc(withSidecarNodes(asEditableLink('link', undefined, function () { return ({ groupLabel: 'Menu Link' }); }))); };
/**
 * HOC that adds a default Editors to the menu Title and Link.
 * Transforms Link into Editable Bodiless Link Toggle and Title to Editable.
 */
var withDefaultMenuTitleEditors = withDesign({
    Link: asMenuLink(withBodilessLinkToggle(asBodilessLink, startWith(A), true)),
    Title: flowHoc(startWith(Fragment), asEditable('text', 'Menu Item')),
});
/**
 * A helper to apply provided `withTitleEditors` HOC to the Title menu key.
 * Applies `withDefaultMenuTitleEditors` token by default.
 *
 * @param withTitleEditors HOC that will be applied to the Title key
 */
var withMenuTitleEditors = function (withTitleEditors) {
    if (withTitleEditors === void 0) { withTitleEditors = withDefaultMenuTitleEditors; }
    var tokenDefs = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        tokenDefs[_i - 1] = arguments[_i];
    }
    return withDesign({
        Title: flowHoc.apply(void 0, __spreadArray([withTitleEditors], tokenDefs, false)),
    });
};
/**
 * HOC that transforms component into MenuTitle with node and 'title' nodeKey.
 * MenuTitle has Link and Title design keys. Can be applied to the Title design key.
 */
var asMenuTitle = flowHoc(startWith(MenuTitle), withNode, withNodeKey('title'));
/**
 * HOC that transforms component into Menu Card with node and 'title' nodeKey.
 * Can be applied to the Title design key.
 */
var asMenuCard = flowHoc(startWith(CardClean), withNode, withNodeKey('title'));
export default MenuTitle;
export { DEFAULT_NODE_KEYS, withMenuTitleEditors, withDefaultMenuTitleEditors, asMenuCard, asMenuTitle, };
//# sourceMappingURL=MenuTitles.js.map