/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { useRef, useCallback, useEffect, } from 'react';
import { withParent, withAppendChild, useNode, useClickOutside, withChild, } from '@bodiless/core';
import { useListContext } from '@bodiless/components';
import { addProps, addClasses, withDesign, flowHoc, Nav, Span, designable, flowIf, not, startWith, Button, withFinalDesign, } from '@bodiless/fclasses';
import { useMenuContext } from './withMenuContext';
import { useSubmenuContext } from './withMenuItemContext';
import { DEFAULT_NODE_KEYS } from './MenuTitles';
import ExpandMoreIcon from '../icons/ExpandMore';
var useHasSubmenu = function () { return useSubmenuContext().hasSubmenu; };
var useHasLink = function () {
    var linkNodeKey = DEFAULT_NODE_KEYS.linkNodeKey;
    var node = useNode().node;
    var linkHref = node.child(linkNodeKey);
    return Boolean(linkHref.data.href);
};
var ClickOutside = React.forwardRef(function (props, ref) {
    useClickOutside(ref, props.onClickOutside);
    return null;
});
var FocusOnEsc = React.forwardRef(function (props, ref) {
    if (typeof ref === 'function')
        return null;
    if (ref && ref.current) {
        var escFunction_1 = useCallback(function (event) {
            // Listen for ESC key only
            var key = event.key || event.keyCode;
            if (key === 'Escape' || key === 'Esc' || key === 27) {
                // Search through all refs element Children
                for (var i = ref.current.children.length - 1; i >= 0; i -= 1) {
                    // Find Button ( List:Title element ) and set focus on it when submenu closes with ESC key
                    if (ref.current.children[i].tagName === 'BUTTON') {
                        ref.current.children[i].focus();
                    }
                }
            }
        }, []);
        useEffect(function () {
            ref.current.addEventListener('keyup', escFunction_1, false);
            return function () {
                ref.current.removeEventListener('keyup', escFunction_1, false);
            };
        }, []);
    }
    return null;
});
var asAccessibleMenuTitle = function (isSubmenuIndicator) {
    if (isSubmenuIndicator === void 0) { isSubmenuIndicator = false; }
    return function (Component) { return function (_a) {
        var ariaLabelSuffix = _a.ariaLabelSuffix, rest = __rest(_a, ["ariaLabelSuffix"]);
        var node = useNode().node;
        var titleText = node.child(DEFAULT_NODE_KEYS.titleNodeKey).data.text;
        var ariaLabel = isSubmenuIndicator
            ? "".concat(titleText, " - ").concat(ariaLabelSuffix || 'More')
            : titleText;
        return React.createElement(Component, __assign({ role: "menuitem", "aria-label": ariaLabel }, rest));
    }; };
};
var asAccessibleSubMenuTitle = function (Component) { return function (props) {
    var activeSubmenu = useMenuContext().activeSubmenu;
    var currentItem = useListContext().currentItem;
    return React.createElement(Component, __assign({ "aria-haspopup": "true", "aria-expanded": activeSubmenu === currentItem }, props));
}; };
var withSubmenuToggle = function (Component) { return function (props) {
    var _a = useMenuContext(), activeSubmenu = _a.activeSubmenu, setActiveSubmenu = _a.setActiveSubmenu;
    var currentItem = useListContext().currentItem;
    var toggleSubmenu = function () { return (activeSubmenu === currentItem
        ? setActiveSubmenu(undefined)
        : setActiveSubmenu(currentItem)); };
    return React.createElement(Component, __assign({}, props, { onClick: toggleSubmenu }));
}; };
var AccessibleMenuItem = function (props) {
    var _a = useMenuContext(), activeSubmenu = _a.activeSubmenu, setActiveSubmenu = _a.setActiveSubmenu;
    var currentItem = useListContext().currentItem;
    var ref = useRef(null);
    return (React.createElement(React.Fragment, null,
        React.createElement("li", __assign({ ref: ref }, props)),
        activeSubmenu === currentItem
            && (React.createElement(React.Fragment, null,
                React.createElement(ClickOutside, { ref: ref, onClickOutside: function () { return setActiveSubmenu(undefined); } }),
                React.createElement(FocusOnEsc, { ref: ref })))));
};
var withAccessibleSubmenuItem = withDesign({
    OuterWrapper: startWith(AccessibleMenuItem),
});
var SubmenuIndicatorBase = function (_a) {
    var C = _a.components, rest = __rest(_a, ["components"]);
    return (React.createElement(C.Button, __assign({}, rest),
        React.createElement(C.Title, null)));
};
var SubmenuIndicatorComponents = {
    Button: Button,
    Title: Span,
};
/**
 * Clean component that renders Submenu Indicator.
 *
 * @see SubmenuIndicatorComponents for a list of design components.
 */
var SubmenuIndicatorClean = designable(SubmenuIndicatorComponents, 'SubmenuIndicator')(SubmenuIndicatorBase);
var SubmenuIndicator = flowHoc(withSubmenuToggle, withDesign({
    Button: flowHoc(asAccessibleMenuTitle(true), asAccessibleSubMenuTitle, addClasses('flex items-center')),
    Title: withChild(ExpandMoreIcon),
}))(SubmenuIndicatorClean);
/**
 * HOC that adds SubmenuIndicator to the Menu Item if
 * it has a submenu and it's title is a link.
 */
var withSubmenuIndicator = flowIf(useHasLink)(withAppendChild(SubmenuIndicator, 'SubmenuIndicator'));
/**
 * HOC that wrappes the component in a navigation region implemented with
 * a nav element that has an aria-label that matches the label on the menubar.
 */
var withMenuNav = flowHoc(withParent(Nav, 'Nav'), withDesign({
    Nav: flowHoc(addClasses('w-full'), addProps({ 'aria-label': 'Main Site Navigation Menu', role: 'navigation' })),
}));
/**
 * HOC that adds an accessibility attributes to the menu
 */
var withAccessibleMenuAttr = withDesign({
    Wrapper: addProps({ role: 'menubar', 'aria-label': 'Navigation Menu' }),
    Title: flowHoc(asAccessibleMenuTitle(), flowIf(function () { return useHasSubmenu() && !useHasLink(); })(asAccessibleSubMenuTitle, withFinalDesign({
        Link: withDesign({
            Link: startWith(Button),
            _default: startWith(Button),
        }),
    }))),
    Item: addProps({ role: 'none' }),
});
/**
 * HOC that wraps menu in the Nav tag and adds an ability
 * to toggle submenus with a keyboard.
 */
var withAccessibleMenuInteractions = withDesign({
    Wrapper: withMenuNav,
    Title: flowIf(useHasSubmenu)(flowIf(not(useHasLink))(withSubmenuToggle)),
});
/**
 * HOC that makes menu accessible.
 * Wraps menu in Nav tag and adds keyboard interactions.
 */
var asAccessibleMenu = flowHoc(withAccessibleMenuAttr, withAccessibleMenuInteractions);
/**
 * HOC that adds the accessibility attributes to the Submenu Wrapper.
 * This includes 'role' and dynamic `aria-labelledby` that corresponds to
 * the menu Item this submenu belongs to.
 */
var withSubmenuWrapperAttrs = function (Component) { return function (props) { return (React.createElement(Component, __assign({ role: "menu", "aria-labelledby": useSubmenuContext().menuItemId }, props))); }; };
/**
 * HOC that adds an accessibility attributes to the Sub Menu.
 */
var withAccessibleSubMenuAttr = withDesign({
    Wrapper: withSubmenuWrapperAttrs,
    Title: asAccessibleMenuTitle(),
    Item: addProps({ role: 'none' }),
});
/**
 * HOC that makes Sub Menu accessible.
 * It adds Sub Menu indicator to the main menu items that have submenus
 * and accessibility attributes to the submenu items.
 */
var asAccessibleSubMenu = flowHoc(withAccessibleSubmenuItem, withSubmenuIndicator, withAccessibleSubMenuAttr);
export { withAccessibleMenuAttr, withAccessibleSubMenuAttr, withAccessibleMenuInteractions, asAccessibleMenu, asAccessibleSubMenu, asAccessibleMenuTitle, };
//# sourceMappingURL=asAccessibleMenu.js.map