var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { withNode, } from '@bodiless/core';
import { asBodilessList, asStylableList, asChameleonSubList, } from '@bodiless/components';
import { withDesign, flowHoc, } from '@bodiless/fclasses';
import { withMenuEditContext } from './withMenuContext';
import { asMenuTitle, DEFAULT_NODE_KEYS } from './MenuTitles';
import { asBreadcrumbSource, asBreadcrumb } from '../Breadcrumbs';
var withChameleonSublist = withDesign({
    Item: asChameleonSubList(function () { return ({ formTitle: 'Sub-Menu Type' }); }),
});
/**
 * Bodiless HOC generator which creates the basic structure of the Bodiless Menu.
 *
 * This serves as a base for various views on the Menu data, including
 * a site's main menu, a burger menu and breadcrumbs.
 *
 * @param nodeKeys Location where the menu state data should be stored.
 * @param defaultData Default menu data.
 * @param useOverrides Hook returning overrides for the menu button.

 * @return HOC which creates a basic mega menu list.
 */
var asBodilessMenu = function (nodeKeys, defaultData, useOverrides) {
    if (useOverrides === void 0) { useOverrides = function () { return ({}); }; }
    return flowHoc(asBodilessList(nodeKeys, defaultData, function (props) { return (__assign({ groupLabel: 'Main Menu Item' }, useOverrides(props))); }), withChameleonSublist, asStylableList, withMenuEditContext, withDesign({ Title: asMenuTitle }), withDesign({
        Item: flowHoc(asBreadcrumb(DEFAULT_NODE_KEYS)),
    }), asBreadcrumbSource, withNode);
};
export default asBodilessMenu;
//# sourceMappingURL=asBodilessMenu.js.map