/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { HOC } from '@bodiless/fclasses';
declare type MenuContextType = {
    activeSubmenu?: string;
    setActiveSubmenu: (id?: string) => void;
};
/**
 * Hook which can be used to get a current active submenu ID
 * and a setter to set active submenu.
 */
declare const useMenuContext: () => MenuContextType;
/**
 * HOC that wrapps component in MenuContextProvider.
 * It stores `activeSubmenu` along with `setActiveSubmenu` setter.
 * Note that `activeSubmenu` is a string and corresponds to the top menu item node id.
 */
declare const withMenuContext: HOC;
/**
 * HOC that wrapps component in PageContextProvider with type="menu" and unique id.
 * Used by useIsMenuOpen() to determine if menu context is active.
 */
declare const withMenuEditContext: HOC;
/**
 * Hook which can be used to determine if menu context is activated.
 *
 * @return true if context for any of Items is active, false otherwise.
 */
declare const useIsMenuOpen: () => boolean;
export default withMenuContext;
export { withMenuEditContext, useIsMenuOpen, useMenuContext, };
//# sourceMappingURL=withMenuContext.d.ts.map