/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { createContext, useContext, useState, } from 'react';
import { PageContextProvider, useEditContext, useUUID } from '@bodiless/core';
var MenuContext = createContext({
    activeSubmenu: undefined,
    setActiveSubmenu: function () { return null; },
});
/**
 * Hook which can be used to get a current active submenu ID
 * and a setter to set active submenu.
 */
var useMenuContext = function () { return useContext(MenuContext); };
var MenuContextProvider = function (_a) {
    var children = _a.children;
    var _b = useState(), activeSubmenu = _b[0], setActiveSubmenu = _b[1];
    return (React.createElement(MenuContext.Provider, { value: { activeSubmenu: activeSubmenu, setActiveSubmenu: setActiveSubmenu } }, children));
};
/**
 * HOC that wrapps component in MenuContextProvider.
 * It stores `activeSubmenu` along with `setActiveSubmenu` setter.
 * Note that `activeSubmenu` is a string and corresponds to the top menu item node id.
 */
var withMenuContext = function (Component) { return function (props) { return (React.createElement(MenuContextProvider, null,
    React.createElement(Component, __assign({}, props)))); }; };
/**
 * HOC that wrapps component in PageContextProvider with type="menu" and unique id.
 * Used by useIsMenuOpen() to determine if menu context is active.
 */
var withMenuEditContext = function (Component) { return function (props) { return (React.createElement(PageContextProvider, { type: "menu", name: "menu-".concat(useUUID()), id: "menu-".concat(useUUID()) },
    React.createElement(Component, __assign({}, props)))); }; };
/**
 * Hook which can be used to determine if menu context is activated.
 *
 * @return true if context for any of Items is active, false otherwise.
 */
var useIsMenuOpen = function () {
    // Move up the context tree to see if we find an active menu context.
    for (var context = useEditContext(); context; context = context.parent) {
        if (context.isEdit && context.type === 'menu' && context.isActive)
            return true;
    }
    return false;
};
export default withMenuContext;
export { withMenuEditContext, useIsMenuOpen, useMenuContext, };
//# sourceMappingURL=withMenuContext.js.map