/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
import { withDesignAt, flowHoc, } from '@bodiless/fclasses';
var withSecondLevelDesign = function (keys) { return keys.reduce(function (result, item) {
    result.push(['Item', item]);
    return result;
}, []); };
var withThirdLevelDesign = function (keys) { return (keys.includes('Columns')
    ? [['Item', 'Columns', 'Item', 'SubList']]
    : []); };
// @todo think about implementation
var depthDesignPathOptions = [function () { return []; }, withSecondLevelDesign, withThirdLevelDesign];
/**
 * Helper which makes it easier to target a particular type of submenu.
 *
 * The first parameter is a list of the submenu key(s) and the second param is the design keys depth
 * to which the tokens provided as a second argument should be applied.
 * It also accepts the special key 'Main' to apply the design to the top level menu.
 *
 * @example
 * ```js
 * withMenuDesign('Columns') -- Applies tokens to all levels of columns submenu.
 * withMenuDesign('Columns', 1) -- Applies tokens to only the first level of Columns submenu.
 * withMenuDesign('Columns', 2) -- Applies tokens to only the second level of Columns submenu.
 *
 * withMenuDesign('Main') -- Applies tokens to the Top menu.
 * withMenuDesign('Cards') -- Applies tokens to Cards submenu.
 * withMenuDesign('List') -- Applies tokens to List submenu.
 *
 * withMenuDesign() -- Applies tokens to the Top menu and all submenus.
 * withMenuDesign(undefined, 0) -- Applies tokens to the Top menu.
 * withMenuDesign(undefined, 1) -- Applies tokens to all submenus of level 1.
 * withMenuDesign(undefined, 2) -- Applies tokens to all submenus of level 2.
 * ```
 *
 * @param keys List of the submenu key(s) to which the token should be applied.
 * @param depths List of menu depth to which the token should be applied to.
 * @param tokenDefs List of tokens to be applied to submenu design key(s).
 *
 * @return Design token that applies supplied list of tokens to the provided design keys.
 */
var withMenuDesign = function (keys, depths) {
    if (keys === void 0) { keys = ['Main', 'List', 'Columns', 'Cards']; }
    if (depths === void 0) { depths = [0, 1, 2]; }
    return function () {
        var tokenDefs = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            tokenDefs[_i] = arguments[_i];
        }
        var keys$ = Array.isArray(keys) ? keys : [keys];
        var depths$ = Array.isArray(depths) ? depths : [depths];
        var submenuDesignPaths = [];
        depths$
            .filter(function (d) { return d < 3 && d > 0; })
            .forEach(function (d) { return submenuDesignPaths.push.apply(submenuDesignPaths, depthDesignPathOptions[d](keys$.filter(function (k) { return k !== 'Main'; }))); });
        // Make sure depths take precedence.
        // For example withMenuDesign(Main, 1) will not do anything.
        if (keys$.includes('Main') && depths$.includes(0)) {
            return flowHoc.apply(void 0, __spreadArray(__spreadArray([{}], tokenDefs, false), [withDesignAt.apply(void 0, submenuDesignPaths)(flowHoc.apply(void 0, __spreadArray([{}], tokenDefs, false)))], false));
        }
        return withDesignAt.apply(void 0, submenuDesignPaths)(flowHoc.apply(void 0, __spreadArray([{}], tokenDefs, false)));
    };
};
export default withMenuDesign;
//# sourceMappingURL=withMenuDesign.js.map