/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { createContext, useContext, } from 'react';
import { useNode } from '@bodiless/core';
import { DEFAULT_NODE_KEYS } from './MenuTitles';
var SubmenuContext = createContext({
    hasSubmenu: false,
    menuItemId: '',
    menuItemTitle: '',
});
var useSubmenuContext = function () { return useContext(SubmenuContext); };
var SubmenuProvider = function (_a) {
    var children = _a.children, hasSubmenu = _a.hasSubmenu, menuItemId = _a.menuItemId, menuItemTitle = _a.menuItemTitle;
    return (React.createElement(SubmenuContext.Provider, { value: { hasSubmenu: hasSubmenu, menuItemId: menuItemId, menuItemTitle: menuItemTitle } }, children));
};
/**
 * HOC that wrapps component in SubmenuProvider.
 * It stores `hasSubmenu` and `isSubmenuOpen` values along with `setIsSubmenuOpen` setter.
 */
var withSubmenuContext = function (Component) { return function (props) {
    // Generate Random Menu Item ID for submenu linking purposes.
    var menuItemId = "menu-item-".concat(Math.random().toString(36).slice(-6));
    var node = useNode().node;
    var parentNode = node.peer(node.path.slice(0, node.path.length - 1));
    var menuItemTextNode = parentNode.child(DEFAULT_NODE_KEYS.titleNodeKey);
    var menuItemText = menuItemTextNode.data.text;
    return (React.createElement(SubmenuProvider, { hasSubmenu: true, menuItemId: menuItemId, menuItemTitle: menuItemText },
        React.createElement(Component, __assign({ label: menuItemId }, props))));
}; };
export { withSubmenuContext, useSubmenuContext, };
//# sourceMappingURL=withMenuItemContext.js.map