/**
 * Copyright © 2020 Johnson & Johnson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import flow from 'lodash/flow';
import { withDesign, flowHoc, withFinalDesign, flowIf, } from '@bodiless/fclasses';
import { asStylableSubList, asSubList, withDeleteNodeOnUnwrap, withSubLists, useListContext, } from '@bodiless/components';
import { asBreadcrumb } from '../Breadcrumbs';
import { asMenuTitle, asMenuCard, DEFAULT_NODE_KEYS, } from './MenuTitles';
/**
 * Creates a stylable sublist which deletes it's data when the last item is removed.
 * Suitable for use for all menus.
 *
 * @param titleDesign token which will be applied to the sublist title.
 * @param useOverrides optional hook returning overrides for the submenu button.
 */
var asMenuSubList = function (withTitleDesign, useOverrides) {
    if (useOverrides === void 0) { useOverrides = function () { return ({}); }; }
    return flow(asSubList(function (props) { return (__assign({ groupLabel: 'Sub-Menu Item' }, useOverrides(props))); }), asStylableSubList, withDeleteNodeOnUnwrap('sublist'), 
    // We must use withFinalDesign to ensure that asBreadcrumb uses the correct node
    // when the item is a sublist. Skip `overview` list items.
    withFinalDesign({
        Item: flowIf(function () { return useListContext().currentItem !== 'overview'; })(asBreadcrumb(DEFAULT_NODE_KEYS)),
    }), withDesign({
        Title: withTitleDesign,
    }));
};
var withSubMenuDesign = function (design) { return withDesign({
    Item: withDesign(design),
}); };
/**
 * Helper which can be used to add a List submenu option to the menu.
 *
 * @param withTitleDesign optional token which will be applied to the sublist title.
 *
 */
var withListSubMenu = function (withTitleDesign) { return withSubMenuDesign({
    List: asMenuSubList(flowHoc(asMenuTitle, withTitleDesign)),
}); };
/**
 * Helper which can be used to add a Cards submenu option to the menu.
 *
 * @param withTitleDesign optional token which will be applied to the sublist title.
 *
 */
var withCardsSubMenu = function (withTitleDesign) { return withSubMenuDesign({
    Cards: asMenuSubList(flowHoc(asMenuCard, withTitleDesign)),
}); };
/**
 * Helper which can be used to add a Columns submenu option to the menu.
 *
 * @param withTitleDesign optional token which will be applied to the sublist title.
 *
 */
var withColumnSubMenu = function (withTitleDesign) { return withSubMenuDesign({
    Columns: flowHoc(asMenuSubList(flowHoc(asMenuTitle, withTitleDesign)), withSubLists(1)(asMenuSubList(flowHoc(asMenuTitle, withTitleDesign), function () { return ({ groupLabel: 'Column Sub-Menu Item' }); }))),
}); };
export { withListSubMenu, withCardsSubMenu, withColumnSubMenu, };
//# sourceMappingURL=withSubMenu.js.map